(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     11156,        302]
NotebookOptionsPosition[     10376,        273]
NotebookOutlinePosition[     10885,        292]
CellTagsIndexPosition[     10842,        289]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["LGSBlochInit",
 FontFamily->"Arial",
 FontSize->22]], "Title",
 InitializationGroup->True],

Cell[TextData[StyleBox["Initialize LGS simulation. Ron Holzlohner 08Dec11",
 FontFamily->"Verdana",
 FontSize->10]], "Text",
 InitializationGroup->True],

Cell[TextData[{
 StyleBox["Usage:",
  FontFamily->"Verdana",
  FontSize->10],
 "\n\tGet[\[OpenCurlyDoubleQuote]LGSBlochInit.m\[CloseCurlyDoubleQuote]];",
 StyleBox["\nInput:\n\tneglectHfs (default: True) If true, include Hyperfine \
states\nOutput:\n\tNone\nAfter the successful execution of initLGSBloch[], \
the global variable NaD2LGS is defined, e.g. for use as in ",
  FontFamily->"Verdana",
  FontSize->10],
 "PsiMeso[NaD2LGS",
 StyleBox["]. It is best to run this routine before anything else in a ",
  FontFamily->"Verdana",
  FontSize->10],
 StyleBox["Mathematica",
  FontFamily->"Verdana",
  FontSize->10,
  FontSlant->"Italic"],
 StyleBox[" session or right after Quit[].\n\nSet neglectHfs to \
\[OpenCurlyDoubleQuote]False\[CloseCurlyDoubleQuote] in order to include the \
Hyperfine states (leads to significantly larger \nequation system). However, \
a test on 20Nov11 yielded differences of a few tenths of a percent \nwhen \
running PsiMeso[] with the option RefineResults->{100,150}",
  FontFamily->"Verdana",
  FontSize->10]
}], "Text",
 InitializationGroup->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"LGSBlochInitwasLoaded", "=", 
   RowBox[{"AbsoluteTime", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Off", "[", 
   RowBox[{"Void", "::", "shdw"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Off", "[", "\[NoBreak]", 
   StyleBox[
    RowBox[{"Set", "::", "write"}], "MessageName"], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Off", "[", "\[NoBreak]", 
   StyleBox[
    RowBox[{"SetDelayed", "::", "write"}], "MessageName"], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Get", "[", "\"\<AtomicDensityMatrix`LGSBloch`\>\"", "]"}], "//", 
    "Quiet"}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ClearAll", "[", "initLGSBloch", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"initLGSBloch", "[", 
    RowBox[{"neglectHfs_:", "True"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"initFileName", ",", "loadEqns", ",", "rval", ",", "rr"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "file", " ", "name", " ", "to", " ", "store", " ", "Bloch", " ", 
       "equation", " ", "system"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"initFileName", " ", "=", " ", 
       RowBox[{"ToFileName", "[", 
        RowBox[{"TmpDir", ",", 
         RowBox[{"\"\<NaD2LGS_\>\"", " ", "<>", " ", 
          RowBox[{"If", "[", 
           RowBox[{"neglectHfs", ",", "\"\<\>\"", ",", "\"\<hfs_\>\""}], 
           "]"}], " ", "<>", " ", "$System", " ", "<>", " ", 
          "\"\<.mx\>\""}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"Load", " ", "system", " ", "if", " ", "it", " ", "exists"}], 
        ",", " ", 
        RowBox[{"is", " ", "large", " ", "enough"}], ",", " ", 
        RowBox[{"and", " ", "is", " ", "newer", " ", "than", " ", 
         RowBox[{"LGSBloch", ".", "m"}]}], ",", " ", 
        RowBox[{"otherwise", " ", "compute", " ", "it"}]}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"NaD2LGS", "=", 
       RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"loadEqns", " ", "=", " ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"FileExistsQ", "[", "initFileName", "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"FileByteCount", "[", "initFileName", "]"}], ">", 
             "2000"}], "&&", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"AbsoluteTime", "[", 
              RowBox[{"FileDate", "[", 
               RowBox[{
               "FindFile", "[", "\"\<AtomicDensityMatrix/LGSBloch.m\>\"", 
                "]"}], "]"}], "]"}], " ", "<", " ", 
             RowBox[{"AbsoluteTime", "[", 
              RowBox[{"FileDate", "[", "initFileName", "]"}], "]"}]}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Get", "[", "initFileName", "]"}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Dimensions", "[", "NaD2LGS", "]"}], " ", "==", " ", 
               RowBox[{"{", "11", "}"}]}], ",", "True", ",", "False"}], 
             "]"}]}], "\[IndentingNewLine]", ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Print", "[", 
             RowBox[{
             "initFileName", ",", 
              "\"\< is outdated or too small, recomputing\>\""}], "]"}], ";", 
            "False"}]}], "]"}], "\[IndentingNewLine]", ",", 
         "\[IndentingNewLine]", "False"}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{"loadEqns", ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<initLGSBloch[]: Loading Bloch equation file \>\"", ",", " ", 
           "initFileName"}], "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"Get", "[", "initFileName", "]"}]}], "\[IndentingNewLine]", 
        ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
         "Print", "[", 
          "\"\<initLGSBloch[]: Computing Bloch equation system. This may take \
a few minutes...\>\"", "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"NaD2LGS", " ", "=", " ", 
          RowBox[{"GenerateLGSSystem", "[", 
           RowBox[{"NeglectHyperfineCoherences", "->", "neglectHfs"}], 
           "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"DumpSave", "[", 
          RowBox[{"initFileName", ",", " ", "NaD2LGS"}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<...done. Saved Bloch equation system to \>\"", ",", " ", 
           "initFileName", ",", " ", "\"\<.\>\""}], "]"}], ";"}]}], 
       "\[IndentingNewLine]", "]"}], ";", "\n", "\n", 
      RowBox[{"(*", " ", 
       RowBox[{"test", " ", 
        RowBox[{"simulation", ".", " ", "Slightly"}], " ", "higher", " ", 
        "return", " ", "if", " ", "NeglectHyperfineCoherences", " ", "True", 
        " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
          "density", " ", "matrix", " ", "blocks", " ", "have", " ", "576", 
           " ", "dimensions", " ", "then"}], ",", " ", 
          RowBox[{"up", " ", "from", " ", "322"}]}], ")"}]}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"rval", "=", 
       RowBox[{"If", "[", 
        RowBox[{"neglectHfs", ",", " ", "262.095", ",", " ", "260.881"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"rr", "=", 
       RowBox[{"PsiMeso", "[", 
        RowBox[{"NaD2LGS", ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"IMeso", "->", "46.0"}], ",", 
           RowBox[{"RepumpFraction", "->", "0.12"}], ",", 
           RowBox[{"BG", "->", "BGParanal"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<initLGSBloch[]: Test result psi: \>\"", ",", " ", "rr", ",", " ", 
        "\"\< ph/s/sr/(W/m^2)\>\""}], "]"}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Abs", "[", 
           RowBox[{"rr", "-", "rval"}], "]"}], "/", "rval"}], " ", "<", " ", 
         "0.001"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{"\"\<Test result ok, ready to go! hfs: \>\"", ",", " ", 
           RowBox[{"!", "neglectHfs"}]}], "]"}], ";"}], "\[IndentingNewLine]",
         ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<Test result should have been \>\"", ",", " ", "rval", ",", 
           " ", "\"\<, suspecting error, Aborting\>\""}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"NaD2LGS", "=", 
          RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"Abort", "[", "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
      ";"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}]}], ";", 
  RowBox[{"(*", " ", 
   RowBox[{"End", " ", "of", " ", "module"}], " ", "*)"}]}]}], "Input",
 InitializationCell->True,
 InitializationGroup->True],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Now", " ", "execute", " ", "the", " ", "initialization"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"initLGSBloch", "[", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"On", "[", 
     RowBox[{"Void", "::", "shdw"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"On", "[", "\[NoBreak]", 
     StyleBox[
      RowBox[{"Set", "::", "write"}], "MessageName"], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"On", "[", "\[NoBreak]", 
     RowBox[{
      StyleBox["SetDelayed", "MessageName"], 
      StyleBox["::", "MessageName"], "write"}], "]"}], ";"}]}]}]], "Input"]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
WindowSize->{961, 918},
WindowMargins->{{Automatic, 32}, {Automatic, -10}},
TrackCellChangeTimes->False,
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.25, 1.25 Inherited],
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (February 23, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 114, 3, 83, "Title",
 InitializationGroup->True],
Cell[684, 27, 152, 3, 33, "Text",
 InitializationGroup->True],
Cell[839, 32, 1081, 26, 254, "Text",
 InitializationGroup->True],
Cell[1923, 60, 7449, 177, 1180, "Input",
 InitializationCell->True,
 InitializationGroup->True],
Cell[9375, 239, 273, 9, 6, "Text"],
Cell[9651, 250, 709, 20, 124, "Input"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
